@@ -35,6 +35,7 @@ class NWPDataSource(ZarrDataSource):
                 hcc   : High-level cloud cover in %.
                 sde   : Snow depth in meters.
                 hcct  : Height of convective cloud top, meters above surface.
+                        WARNING: hcct has NaNs where there are no clouds forecast to exist!
                 dswrf : Downward short-wave radiation flux in W/m^2 (irradiance) at surface.
                 dlwrf : Downward long-wave radiation flux in W/m^2 (irradiance) at surface.
                 h     : Geometrical height, meters.
@@ -69,6 +70,11 @@ class NWPDataSource(ZarrDataSource):
             image_size_pixels,
             image_size_pixels,
         )
+        _LOG.info(
+            f"NWPDataSource instantiated with {self.channels=},"
+            f" {self._square.size_pixels=},"
+            f" {self.zarr_path=}"
+        )
 
     def open(self) -> None:
         """
@@ -79,11 +85,12 @@ class NWPDataSource(ZarrDataSource):
         instances into separate processes.  Instead,
         call open() _after_ creating separate processes.
         """
-        data = self._open_data()
-        self._data = data.sel(variable=list(self.channels))
+        self._data = self._open_data()
+        np.testing.assert_array_equal(self._data["variable"].values, self.channels)
 
     def _open_data(self) -> xr.DataArray:
-        return open_nwp(self.zarr_path, consolidated=self.consolidated)
+        data = open_nwp(self.zarr_path, consolidated=self.consolidated)
+        return data.sel(variable=list(self.channels))
 
     @staticmethod
     def get_data_model_for_batch():
@@ -181,7 +188,8 @@ def open_nwp(zarr_path: str, consolidated: bool) -> xr.DataArray:
         engine="zarr",
         consolidated=consolidated,
         mode="r",
-        chunks="auto",  # See issue #456 for why we use "auto".
+        chunks=None,  # Reading Satellite Zarr benefits from setting chunks='auto' (see issue #456)
+        # but 'auto' massively slows down reading NWPs.
     )
 
     # Select the "UKV" DataArray from the "nwp" Dataset.
