@@ -38,8 +38,8 @@ def test_sample_spatial_and_temporal_locations_for_examples():  # noqa: D103
 
     gsp = GSPDataSource(
         zarr_path=f"{local_path}/tests/data/gsp/test.zarr",
-        start_dt=datetime(2020, 4, 1),
-        end_dt=datetime(2020, 4, 2),
+        start_datetime=datetime(2020, 4, 1),
+        end_datetime=datetime(2020, 4, 2),
         history_minutes=30,
         forecast_minutes=60,
         image_size_pixels=64,
@@ -139,8 +139,8 @@ def test_batches():
 
     gsp = GSPDataSource(
         zarr_path=filename,
-        start_dt=datetime(2020, 4, 1),
-        end_dt=datetime(2020, 4, 2),
+        start_datetime=datetime(2020, 4, 1),
+        end_datetime=datetime(2020, 4, 2),
         history_minutes=30,
         forecast_minutes=60,
         image_size_pixels=64,
